package com.ynet.life.formValidation;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.File;
import java.util.HashMap;
import java.util.Map;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/* loaded from: com_ynet_life_formValidation.jar:com/ynet/life/formValidation/FormValidationConfigXMLReader.class */
public class FormValidationConfigXMLReader {
    private static final String XML_TAG_CLASS_ID = "id";
    private static final String XML_TAG_CLASS_NAME = "class";
    private static final String XML_TAG_ITEM_ID = "businessCode";
    private static final String XML_TAG_CONFIG_FIELD = "field";
    private static final String XML_TAG_DATA_NAME = "name";
    private static final String XML_TAG_DATA_TYPE = "type";
    private static final String XML_TAG_DATA_ERROECORE = "errorCode";
    private static final String XML_TAG_DATA_VALUE = "value";
    private static final Map CLASS_FIELD_MAP = new HashMap();
    private Node rootNode;

    public FormValidationConfigXMLReader(String fileName) {
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setValidating(false);
            NodeList list = factory.newDocumentBuilder().parse(new File(fileName)).getChildNodes();
            for (int i = 0; i < list.getLength(); i++) {
                if (list.item(i) instanceof Element) {
                    this.rootNode = list.item(i);
                    return;
                }
            }
        } catch (Exception ex) {
            Trace.logError("LOAF", "读入配置文件失败", ex);
        }
    }

    public Map getConfigs() throws TranFailException {
        String businessCode;
        Map configs = new HashMap();
        NodeList classNodeList = this.rootNode.getChildNodes().item(1).getChildNodes();
        int size = classNodeList.getLength();
        for (int i = 0; i < size; i++) {
            Node node = classNodeList.item(i);
            if (node.getNodeType() == 1) {
                String classId = getNodeAttributeValue(XML_TAG_CLASS_ID, node);
                String className = getNodeAttributeValue(XML_TAG_CLASS_NAME, node);
                if (classId != null && className != null) {
                    CLASS_FIELD_MAP.put(classId, className);
                }
            }
        }
        NodeList configNodeList = this.rootNode.getChildNodes().item(3).getChildNodes();
        int size2 = configNodeList.getLength();
        for (int i2 = 0; i2 < size2; i2++) {
            Node node2 = configNodeList.item(i2);
            if (node2.getNodeType() == 1 && (businessCode = getNodeAttributeValue(XML_TAG_ITEM_ID, node2)) != null) {
                FormValidationConfig newConfig = new FormValidationConfig(businessCode);
                NodeList fieldNodeList = node2.getChildNodes();
                int languageNodeSize = fieldNodeList.getLength();
                for (int j = 0; j < languageNodeSize; j++) {
                    Node child = fieldNodeList.item(j);
                    if (child.getNodeType() == 1 && child.getNodeName().equals(XML_TAG_CONFIG_FIELD)) {
                        addConfigField(newConfig, child);
                    }
                }
                String[] codes = businessCode.split(FormValidationConstants.FIELD_DATA_FIX);
                for (String str : codes) {
                    configs.put(str, newConfig);
                }
            }
        }
        return configs;
    }

    public void addConfigField(FormValidationConfig newConfig, Node configFieldNode) throws TranFailException {
        String dataFieldName = getNodeAttributeValue(XML_TAG_DATA_NAME, configFieldNode);
        String dataType = getNodeAttributeValue(XML_TAG_DATA_TYPE, configFieldNode);
        String dataFieldValue = getNodeAttributeValue(XML_TAG_DATA_VALUE, configFieldNode);
        String dataErrorCode = getNodeAttributeValue(XML_TAG_DATA_ERROECORE, configFieldNode);
        if (dataErrorCode == null || "".equals(dataErrorCode)) {
            throw new TranFailException("EBLN0000", "errorCode为空");
        }
        if (dataFieldName == null || dataType == null) {
            throw new TranFailException("EBLN0000", "数据域名称或者校验规则为空：name = " + dataFieldName + ", type = " + dataType);
        }
        if (dataFieldValue == null || "".equals(dataFieldValue.trim())) {
            dataFieldValue = dataFieldName;
        }
        Map dataTypeMap = new FormValidationDataTypeParse().parseDataType(dataType);
        newConfig.addDataTableField(getKey(dataFieldName, dataFieldValue, dataErrorCode), dataTypeMap);
    }

    private String getNode(Node dataFieldNode) {
        if (dataFieldNode == null) {
            return null;
        }
        return dataFieldNode.getNodeValue();
    }

    public String getNodeAttributeValue(String attrName, Node aNode) {
        if (aNode != null && attrName != null && attrName.trim().length() != 0 && aNode.getAttributes().getNamedItem(attrName) != null) {
            return aNode.getAttributes().getNamedItem(attrName).getNodeValue();
        }
        return null;
    }

    private static String getKey(String dataName, String fieldValue, String dataErrorCode) {
        return String.valueOf(dataName) + FormValidationConstants.FIELD_VAR_FIX + fieldValue + FormValidationConstants.FIELD_VAR_FIX + dataErrorCode;
    }

    public static boolean isDefined(String key) {
        return CLASS_FIELD_MAP.containsKey(key);
    }

    public static String getData(String key) {
        return (String) CLASS_FIELD_MAP.get(key);
    }
}
